@@ -1,11 +1,22 @@
-from datetime import datetime, timedelta
+from datetime import (
+    datetime,
+    timedelta,
+)
 import re
 
 import numpy as np
 import pytest
 
-import pandas as pd
-from pandas import Index, Timedelta, TimedeltaIndex, notna, timedelta_range
+from pandas import (
+    Index,
+    NaT,
+    Timedelta,
+    TimedeltaIndex,
+    Timestamp,
+    notna,
+    timedelta_range,
+    to_timedelta,
+)
 import pandas._testing as tm
 
 
@@ -55,10 +66,10 @@ class TestGetItem:
     @pytest.mark.parametrize(
         "key",
         [
-            pd.Timestamp("1970-01-01"),
-            pd.Timestamp("1970-01-02"),
+            Timestamp("1970-01-01"),
+            Timestamp("1970-01-02"),
             datetime(1970, 1, 1),
-            pd.Timestamp("1970-01-03").to_datetime64(),
+            Timestamp("1970-01-03").to_datetime64(),
             # non-matching NA values
             np.datetime64("NaT"),
         ],
@@ -72,7 +83,7 @@ class TestGetItem:
 
 class TestGetLoc:
     def test_get_loc(self):
-        idx = pd.to_timedelta(["0 days", "1 days", "2 days"])
+        idx = to_timedelta(["0 days", "1 days", "2 days"])
 
         for method in [None, "pad", "backfill", "nearest"]:
             assert idx.get_loc(idx[1], method) == 1
@@ -108,7 +119,7 @@ class TestGetLoc:
     def test_get_loc_nat(self):
         tidx = TimedeltaIndex(["1 days 01:00:00", "NaT", "2 days 01:00:00"])
 
-        assert tidx.get_loc(pd.NaT) == 1
+        assert tidx.get_loc(NaT) == 1
         assert tidx.get_loc(None) == 1
         assert tidx.get_loc(float("nan")) == 1
         assert tidx.get_loc(np.nan) == 1
@@ -116,12 +127,12 @@ class TestGetLoc:
 
 class TestGetIndexer:
     def test_get_indexer(self):
-        idx = pd.to_timedelta(["0 days", "1 days", "2 days"])
+        idx = to_timedelta(["0 days", "1 days", "2 days"])
         tm.assert_numpy_array_equal(
             idx.get_indexer(idx), np.array([0, 1, 2], dtype=np.intp)
         )
 
-        target = pd.to_timedelta(["-1 hour", "12 hours", "1 day 1 hour"])
+        target = to_timedelta(["-1 hour", "12 hours", "1 day 1 hour"])
         tm.assert_numpy_array_equal(
             idx.get_indexer(target, "pad"), np.array([-1, 0, 1], dtype=np.intp)
         )
@@ -148,30 +159,39 @@ class TestWhere:
     def test_where_invalid_dtypes(self):
         tdi = timedelta_range("1 day", periods=3, freq="D", name="idx")
 
-        i2 = Index([pd.NaT, pd.NaT] + tdi[2:].tolist())
+        tail = tdi[2:].tolist()
+        i2 = Index([NaT, NaT] + tail)
+        mask = notna(i2)
 
-        msg = "value should be a 'Timedelta', 'NaT', or array of those"
-        with pytest.raises(TypeError, match=msg):
-            tdi.where(notna(i2), i2.asi8)
+        expected = Index([NaT.value, NaT.value] + tail, dtype=object, name="idx")
+        assert isinstance(expected[0], int)
+        result = tdi.where(mask, i2.asi8)
+        tm.assert_index_equal(result, expected)
 
-        with pytest.raises(TypeError, match=msg):
-            tdi.where(notna(i2), i2 + pd.Timestamp.now())
+        ts = i2 + Timestamp.now()
+        expected = Index([ts[0], ts[1]] + tail, dtype=object, name="idx")
+        result = tdi.where(mask, ts)
+        tm.assert_index_equal(result, expected)
 
-        with pytest.raises(TypeError, match=msg):
-            tdi.where(notna(i2), (i2 + pd.Timestamp.now()).to_period("D"))
+        per = (i2 + Timestamp.now()).to_period("D")
+        expected = Index([per[0], per[1]] + tail, dtype=object, name="idx")
+        result = tdi.where(mask, per)
+        tm.assert_index_equal(result, expected)
 
-        with pytest.raises(TypeError, match=msg):
-            # non-matching scalar
-            tdi.where(notna(i2), pd.Timestamp.now())
+        ts = Timestamp.now()
+        expected = Index([ts, ts] + tail, dtype=object, name="idx")
+        result = tdi.where(mask, ts)
+        tm.assert_index_equal(result, expected)
 
     def test_where_mismatched_nat(self):
         tdi = timedelta_range("1 day", periods=3, freq="D", name="idx")
         cond = np.array([True, False, False])
 
-        msg = "value should be a 'Timedelta', 'NaT', or array of those"
-        with pytest.raises(TypeError, match=msg):
-            # wrong-dtyped NaT
-            tdi.where(cond, np.datetime64("NaT", "ns"))
+        dtnat = np.datetime64("NaT", "ns")
+        expected = Index([tdi[0], dtnat, dtnat], dtype=object, name="idx")
+        assert expected[2] is dtnat
+        result = tdi.where(cond, dtnat)
+        tm.assert_index_equal(result, expected)
 
 
 class TestTake:
@@ -271,3 +291,52 @@ class TestTake:
         msg = "index -5 is out of bounds for (axis 0 with )?size 3"
         with pytest.raises(IndexError, match=msg):
             idx.take(np.array([1, -5]))
+
+
+class TestMaybeCastSliceBound:
+    @pytest.fixture(params=["increasing", "decreasing", None])
+    def monotonic(self, request):
+        return request.param
+
+    @pytest.fixture
+    def tdi(self, monotonic):
+        tdi = timedelta_range("1 Day", periods=10)
+        if monotonic == "decreasing":
+            tdi = tdi[::-1]
+        elif monotonic is None:
+            taker = np.arange(10, dtype=np.intp)
+            np.random.shuffle(taker)
+            tdi = tdi.take(taker)
+        return tdi
+
+    def test_maybe_cast_slice_bound_invalid_str(self, tdi):
+        # test the low-level _maybe_cast_slice_bound and that we get the
+        #  expected exception+message all the way up the stack
+        msg = (
+            "cannot do slice indexing on TimedeltaIndex with these "
+            r"indexers \[foo\] of type str"
+        )
+        with pytest.raises(TypeError, match=msg):
+            tdi._maybe_cast_slice_bound("foo", side="left")
+        with pytest.raises(TypeError, match=msg):
+            tdi.get_slice_bound("foo", side="left")
+        with pytest.raises(TypeError, match=msg):
+            tdi.slice_locs("foo", None, None)
+
+    def test_slice_invalid_str_with_timedeltaindex(
+        self, tdi, frame_or_series, indexer_sl
+    ):
+        obj = frame_or_series(range(10), index=tdi)
+
+        msg = (
+            "cannot do slice indexing on TimedeltaIndex with these "
+            r"indexers \[foo\] of type str"
+        )
+        with pytest.raises(TypeError, match=msg):
+            indexer_sl(obj)["foo":]
+        with pytest.raises(TypeError, match=msg):
+            indexer_sl(obj)["foo":-1]
+        with pytest.raises(TypeError, match=msg):
+            indexer_sl(obj)[:"foo"]
+        with pytest.raises(TypeError, match=msg):
+            indexer_sl(obj)[tdi[0] : "foo"]
